@@ -130,9 +130,9 @@ public:
                         : ItemCreator(className, worldModel, worldScene),
                           _snapFlags(snapFlags), _snapTypes(snapTypes), _twoEnds(twoEnds) {}
 
-    bool sceneEvent(QEvent* event);
-    void start();
-    void abort();
+    bool sceneEvent(QEvent* event) Q_DECL_OVERRIDE;
+    void start() Q_DECL_OVERRIDE;
+    void abort() Q_DECL_OVERRIDE;
 
 protected:
     WorldScene::SnapFlags _snapFlags;
